@@ -1,7 +1,7 @@
 /*
  *        kmidi
  *
- * $Id: log.cpp,v 1.5 1999/01/14 16:55:35 bieker Exp $
+ * $Id: log.cpp,v 1.5.2.1 1999/06/10 08:47:35 porten Exp $
  *            Copyright (C) 1997  Bernd Wuebben
  *                 wuebben@math.cornel.edu 
  *
@@ -228,8 +228,7 @@ void LogWindow::resizeEvent(QResizeEvent* ){
 
 void LogWindow::enter() {
 
-  char character[3];
-  character = "\r\n";
+  char character[3] = "\r\n";
 
   text_window->append(character);
 
